Developer notes
==========================

.. admonition:: team developer material

   This section is intended to be usefull for team developers only.


Quick installation process
---------------------------------------

This process describes how to install and run the project locally, e.g. for development purposes.

*Nota*: command is to be executed through the terminal

`pip install rougail`
